#
# spec file for package workrave
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define upstream_version    1_10_20
Name:           workrave
Version:        1.10.20
Release:        bp153.1.19
Summary:        Recovery and prevention of Repetitive Strain Injury program
License:        GPL-3.0
Group:          Productivity/Other
URL:            http://www.workrave.org
Source:         https://github.com/rcaelers/workrave/archive/v%{upstream_version}.tar.gz
Source2:        %{name}-rpmlintrc
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibmm2-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  libpulse-devel
BuildRequires:  libsigc++2-devel
BuildRequires:  python-cheetah
BuildRequires:  python-xml
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  xorg-x11-devel
# other requirements that are documented or previously used but (currently?) not needed. let's see if there are problems without them
#BuildRequires:  gdome2-devel
#BuildRequires:  gnome-panel-devel
#BuildRequires:  libbonobo-devel
#BuildRequires:  libgmodule-2_0-0
#BuildRequires:  libgthread-2_0-0
#BuildRequires:  pkg-config
#BuildRequires:  pkgconfig(glib-2.0)
#BuildRequires:  pkgconfig(gstreamer-0.10)
#BuildRequires:  gconfmm-devel
#BuildRequires:  xorg-x11-Xvfb

%description
Workrave is a program that assists in the recovery and prevention of Repetitive Strain Injury (RSI). The program frequently alerts you to take micro-pauses, rest breaks and restricts you to your daily limit.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/Other

%description devel
This package contains header files needed for developing plugins for
Workrave.

%package -n typelib-1_0-Workrave-1_0
Summary:        Introspection bindings for Workrave
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n typelib-1_0-Workrave-1_0
This package contains typelib files needed for developing plugins for
Workrave.

%prep
%setup -q -n %{name}-%{upstream_version}

%build
./autogen.sh
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}/%{_libdir} -type f -name "*.la" -delete
%suse_update_desktop_file %{name}
rm -f %{buildroot}/%{_libdir}/libworkrave-private-1.0.so
%fdupes %{buildroot}/%{_prefix}
%find_lang %{name}

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files -f %{name}.lang
%license COPYING
%doc AUTHORS NEWS README.md ABOUT-NLS
%{_bindir}/workrave
%dir %{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/dbus*/*
%dir %{_datadir}/sounds/%{name}
%{_datadir}/sounds/%{name}/*
%{_datadir}/%{name}/*
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/extensions
%dir %{_datadir}/gnome-shell/extensions/workrave@workrave.org
%{_datadir}/gnome-shell/extensions/workrave@workrave.org/*
%if 0%{?suse_version} > 1140
%{_datadir}/glib-2.0/schemas/org.workrave.enums.xml
%{_datadir}/glib-2.0/schemas/org.workrave.gschema.xml
%{_datadir}/glib-2.0/schemas/org.workrave.gui.gschema.xml
%else
%{_libdir}/bonobo/servers/Workrave-Applet.server
%{_datadir}/gnome-2.0/ui/GNOME_WorkraveApplet.xml
%endif
%{_datadir}/icons/hicolor/
%{_datadir}/appdata/workrave.appdata.xml
%{_datadir}/cinnamon/applets/workrave@workrave.org/applet.js
%{_datadir}/cinnamon/applets/workrave@workrave.org/metadata.json
%dir /usr/share/cinnamon/
%dir /usr/share/cinnamon/applets/
%dir /usr/share/cinnamon/applets/workrave@workrave.org/
%{_libdir}/libworkrave-private-*

%files devel
%{_datadir}/gir-1.0/Workrave-1.0.gir

%files -n typelib-1_0-Workrave-1_0
%{_libdir}/girepository-1.0/Workrave-1.0.typelib

%changelog
* Tue Apr 17 2018 jengelh@inai.de
- Redo typelib package according to other typelib packages
- Un-SLPP private libraries
- Remove -devel subpackage because there are no headers
* Tue Apr 17 2018 sebix+novell.com@sebix.at
- fix packaging or .a, .la files
- add typelib subpackage
- fix ldconfig calls
* Mon Mar 19 2018 sebix+novell.com@sebix.at
- update to version 1.10.20
  * Fix activity monitoring on non-Gnome desktop environments
  * Workrave 1.10.19
  * Fix crash because of missing setting
  * Fix Gnome Shell applet
- update to version 1.10.18
  * Support Gnome Shell 3.24/26
- update to version 1.10.17
  * Update Czech translation (Pavel Bborecki)
- update to version 1.10.16
  * Mark applet as compatible with GNOME 3.22 (Francois Marier)
  * Fix text alignment time bar.
  * Fix resuming microbreak after postponing restbreak
- update to version 1.10.15
  * Fix crash when no shutdown/hibernate options are available.
  * Updated traditional Chinese translation (Kevin Kuan)
- update to version 1.10.14
  * Fixed issue where pressing the down key during a restbreak would
  lock the screen (bug #1242)
- update to version 1.10.13
  * Use button instead of combobox if only 'Lock' is available in
  restbreak window (pedantic-git)
  * Update german translation (rsnitsch)
  * Support Gnome Shell 3.20 (Francois Marier)
- update to version 1.10.12
  * Updated Catalan translation (Jordi Mallach)
  * Fixed Gnome Shell applet (Amir Mohammadi)
- update to version 1.10.11
  * Improved security of network protocol.
  NOTE: this is a backward incompatible change.
  This version of Workrave will no longer connect to older Workrave versions.
  * Minor improvements
- update to version 1.10.9
  * UI tweak
- update to version 1.10.8
  * Extra statistics
  - Weekly usage statistics (Rob Caelers)
  - Monthly usage statistics (Denis Nikolaenko)
  * Fix gtkmm 3.18 compilation (Javier Tia, Denis Nikolaenko)
  * Support Gnome 3.16
- update to version 1.10.7
  * Update translations:
  - Spanish (Fco. Javier Serrador)
- update to version 1.10.6
  * Improved screen lock and shutdown in break window (Mateusz Jończyk)
  * Add suspend/hibernate option to break window on Linux (Mateusz Jończyk)
  * Gnome applet updated to work with latest Gnome 3 flashback (Dmitry Shachnev)
  * Applets added for Cinnamon, XFCE and MATE.
  * Bug fixes:
  - Break window was transparent when blocking mode was set to 'input and screen'
  - Text background in exercises window was black, making the text unreadable.
  - In some cases the timers were shown twice in the panel
- update to version 1.10.5
  * Updated tranlations:
  - Danish (Frederik Svarre)
  * Updates Desktop files (Francois Marier, Mike Manger)
- update to version 1.10.4
  * Fix gnome-shell applet for Gnome 3.12.
- update to version 1.10.3
  * Bug fixes
  - bug 1114: Closing timer window closes program.
  - bug 1120: make the GNOME shell extension compatible with GNOME 3.8
  - bug 1136: Status window always appears on startup
  - bug 1137: Make Workrave start up optional
  - bug 1146: dconf changes not honored for /org/workrave/general/operation-mode
  - bug 1147: Suspend timer during screensaver
  - bug 1148: Double deallocation causes crashes during Workrave shutdown
  - Fix Workrave icon on Unity
  - Fix size of prelude window
  - Fix size of unity indicator timebar
  - Fixed compatibility with gnome-shell 3.10
  - Allow Gnome Shell status icon to be enabled/disabled
- update to version 1.10.1
  * nothing relevant.
- update to version 1.10
  * Split "show 'postpone' and 'skip'" checkbox into two checkboxes. (Egbert Teeselink)
  * Add the capability to delete all stored statistics (Ray Satiro)
  * Workrave now offers a Gnome 3 applet. Applets for both Gnome 3
  classic and the Gnome shell are available.
  * Workrave now offers an application indicator (applet) in Unity.
  * On Unix, Workrave adds a new activity monitoring method that can be
  used instead of the XRECORD based monitoring. XRECORD monitoring
  appear be causing X crashes for some people
  (See http://issues.workrave.org/show_bug.cgi?id=1066)
  * Infrastructure update. Workrave now supports:
  - Gtk3/Gtkmm3 (only on Gnome 3; Gtk2/Gtkmm2 is still used on Gnome 2)
  - Configuration in GSettings (instead of GConf)
  - GIO based DBus (instead of freedesktop.org DBus)
  * Obsolete KDE3 support has been droppped.
  * Translation updates
  * Plus many small fixes and improvements
- remove obsolete workrave-1.9.901-gnome3-panel-makefile.patch
- remove unused workrave-kde-errors.patch
* Mon Nov  7 2011 lijewski.stefan@gmail.com
- update to version 1.9.901 (git branch):
  * correctly build on Factory (gnome3)
  * split packages for Factory
* Mon Apr 11 2011 lijewski.stefan@gmail.com
- update to version 1.9.4
- merge to only one package (without gnome and kde version)
- kde build is broken according to configure options
* Wed Feb 11 2009 sbrabec@suse.cz
- Use correct gstreamer package name.
* Thu Oct 16 2008 sbrabec@suse.cz
- Call intltoolize as last action to prevent build failures.
* Tue Sep 16 2008 ro@suse.de
- fix build regardless of libtool version
* Mon Sep  1 2008 sbrabec@suse.cz
- Updated to version 1.9.0:
  * Fixed transparency of tray icon
  * improved 64 bit support
  * exercises are now randomized
  * extended DBUS support
  * networking support can now be enabled without accepting
    incoming connections from other Workraves
  * sound has been added
* Tue Apr 29 2008 sbrabec@suse.cz
- Added Fedora patches:
  * fix locking/unlocking with gnome-screensaver (redhat#207058)
  * build with gcc-4.3
  * build GNOME applet with the latest libsigc++2
- Fixed build of KDE applet with the latest libsigc++2.
- Added desktop file.
* Mon Oct 29 2007 sbrabec@suse.cz
- Updated to version 1.8.5:
  * Task manager is never blocked by Workrave
  * Many bug fixes, the most visible ones:
  * Fixed breaks that have 'suspend timer when inactive' disabled
  * Mode menu fixed.
  * Gnome applet no longer 'hangs'.
  * Gnome applet no longer crashes Workrave.
  * Fixed 'end-of-microbreak' sound.
  * Fixed bug in multi-head support where Workrave showed multiple
    windows on a single screen.
  * Fixed locking on Gnome with xscreensaver installed
  * Polish on the applets
  * Translations updated
- Fixed gcc 4.3 errors.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Sat Aug 11 2007 mrueckert@suse.de
- switch to %%lang_package -n
- fixed typo in requires of workrave-kde
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off -lang subpackages.
* Sun Jan 28 2007 ro@suse.de
- make it build after GNOME moved to /usr
* Mon Oct 23 2006 sbrabec@suse.cz
- Updated to version 1.8.3:
  * 100%% CPU load fix.
  * GNOME screen saver support added.
  * The applet popup menu is now accessible when all timers hidden.
  * Translations updated.
  * Bug fixes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 23 2005 ro@suse.de
- provide main package name in one subpackage
  (needed for debuginfo since we do not have a main package here)
* Thu Dec 15 2005 sbrabec@suse.cz
- New SuSE package, version 1.8.1.
